@@ -20,6 +20,7 @@ mod keys {
   cluster_test!(keys, should_mget_values);
   cluster_test!(keys, should_msetnx_values);
   cluster_test!(keys, should_copy_values);
+  cluster_test!(keys, should_get_keys_from_pool_in_a_stream);
 }
 
 mod multi {
@@ -43,6 +44,15 @@ mod other {
   cluster_test!(other, should_error_when_blocked);
 }
 
+mod pool {
+  cluster_test!(pool, should_connect_and_ping_static_pool_single_conn);
+  cluster_test!(pool, should_connect_and_ping_static_pool_two_conn);
+  #[cfg(feature = "fd-tests")]
+  cluster_test!(pool, should_connect_and_ping_static_pool_many_conn);
+  #[cfg(feature = "fd-tests")]
+  cluster_test!(pool, should_connect_and_ping_static_pool_repeatedly);
+}
+
 mod hashes {
 
   cluster_test!(hashes, should_hset_and_hget);
